package com.mcwl.web.controller.resource;

import cn.hutool.core.bean.BeanUtil;
import com.mcwl.common.annotation.Anonymous;
import com.mcwl.common.core.controller.BaseController;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.core.page.PageDomain;
import com.mcwl.common.core.page.TableDataInfo;
import com.mcwl.common.utils.SecurityUtils;
import com.mcwl.resource.domain.ModelProduct;
import com.mcwl.resource.domain.dto.ModelImagePageRes;
import com.mcwl.resource.domain.request.RequestModel;
import com.mcwl.resource.service.ModelImageService;
import com.mcwl.resource.service.ModelService;
import com.mcwl.resource.service.WorkFlowService;
import com.mcwl.web.controller.common.OssUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;


/**
 *模型
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.web.controller.resource
 * @Filename：MallProductController
 * @Description 商品
 * @Date：2024/12/31 10:48
 */

@RestController
@RequestMapping("/model")
public class MallProductController extends BaseController {


    @Autowired
    private ModelService modelService;

    @Autowired
    private ModelImageService modelImageService;

    @Autowired
    private WorkFlowService workFlowService;


    /***
     *
     * 图片
     * @param file
     * @return
     */
    @Anonymous
    @PostMapping("/file")
    public AjaxResult Malifile(@RequestParam MultipartFile file) {

        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }


    /***
     *
     * zip
     * @param file
     * @return
     */
    @PostMapping("/zipUrlFile")
    public AjaxResult zipUrlFile(@RequestParam MultipartFile file) {
        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }


    /***
     *
     * 下载zip
     * @param file
     * @return
     */
    @PostMapping("/zipUrl")
    public AjaxResult zipUrl(@RequestParam MultipartFile file) {
        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }


    /**
     * 模型列表
     */
    @PostMapping("/list")
    public TableDataInfo list(@RequestBody ModelImagePageRes imagePageRes) {

        return modelService.listByPage(imagePageRes);
    }


    @PostMapping("finbyid")
    public AjaxResult finbyid(@RequestBody ModelProduct modelVersion) {
        ModelProduct modelVersion1 = modelService.getById(modelVersion.getId());
        return AjaxResult.success(modelVersion1);
    }


    @PostMapping("/insert")
    public AjaxResult addupdateModel(@RequestBody RequestModel requestModel) {
        ModelProduct modelProduct = requestModel.getModelProduct();
        Long userId = SecurityUtils.getUserId();
        modelProduct.setUserId(userId);
        modelProduct.setCreateBy(getUsername());
        return modelService.addModel(requestModel);
    }

    @PostMapping("/update")
    public AjaxResult updateModel(@RequestBody RequestModel requestModel) {
        ModelProduct modelProduct = requestModel.getModelProduct();

        Long userId = SecurityUtils.getUserId();
        modelProduct.setUserId(userId);
        modelProduct.setUpdateBy(getUsername());
        modelService.updaModel(requestModel);

        return AjaxResult.success("修改成功");
    }


    @PostMapping("delete")
    public AjaxResult delete(@RequestBody ModelProduct modelVersion) {
        modelService.removeById(modelVersion.getId());
        return AjaxResult.success();
    }
    /**
     * 查询模型详情
     * @param id
     * @return
     */
    @GetMapping("/selectModelById")
    public AjaxResult selectModelById(@RequestParam Long id){

        return modelService.selectModelById(id);
    }

    /**
     * 我的发布-模型
     */
    @PostMapping("/selectByUserIdModel")
    public TableDataInfo selectByUserIdModel(@RequestBody ModelImagePageRes imagePageRes) {

        return modelService.listByPage(imagePageRes);
    }

    /**
     * 我的发布-工作流
     */
    @PostMapping("/selectByUserIdWorkFlow")
    public TableDataInfo selectByUserIdWorkFlow(@RequestBody ModelImagePageRes imagePageRes) {

        return workFlowService.listByPage(imagePageRes);
    }

    /**
     * 我的发布-图片
     */
    @PostMapping("/selectByUserIdImage")
    public TableDataInfo selectByUserIdImage(@RequestBody ModelImagePageRes imagePageRes) {

        return modelImageService.listByPage(imagePageRes);
    }

    /**
     * 点赞-模型
     */
    @PostMapping("/likeModel")
    public TableDataInfo likeModel(@RequestBody PageDomain pageDomain) {
        ModelImagePageRes imagePageRes = new ModelImagePageRes();
        BeanUtil.copyProperties(pageDomain, imagePageRes);
        imagePageRes.setUserId(SecurityUtils.getUserId());
        return modelService.listByPage(imagePageRes);
    }

    /**
     * 点赞-工作流
     */
    @PostMapping("/likeWorkFlow")
    public TableDataInfo likeWorkFlow(@RequestBody PageDomain pageDomain) {
        ModelImagePageRes imagePageRes = new ModelImagePageRes();
        BeanUtil.copyProperties(pageDomain, imagePageRes);
        imagePageRes.setUserId(SecurityUtils.getUserId());
        return workFlowService.listByPage(imagePageRes);
    }

    /**
     * 点赞-图片
     */
    @PostMapping("/likeImage")
    public TableDataInfo likeImage(@RequestBody PageDomain pageDomain) {
        ModelImagePageRes imagePageRes = new ModelImagePageRes();
        BeanUtil.copyProperties(pageDomain, imagePageRes);
        imagePageRes.setUserId(SecurityUtils.getUserId());
        return modelImageService.listByPage(imagePageRes);
    }


}
