package com.mcwl.web.controller.resource;

import com.mcwl.common.core.controller.BaseController;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.resource.domain.request.RequestWorkFlow;
import com.mcwl.resource.domain.vo.PageVo;
import com.mcwl.resource.service.impl.WorkFlowServiceImpl;
import com.mcwl.web.controller.common.OssUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;


/**
 * 工作流
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.web.controller.resource
 * @Filename：MallProductController
 * @Description 商品
 * @Date：2024/12/31 10:48
 */

@RestController
@RequestMapping("/WorkFlow")
public class WorkFlowController extends BaseController {


    @Autowired
    private WorkFlowServiceImpl workFlowService;

    /***
     * 图片
     * @param file
     * @return
     */
    @PostMapping("/file")
    public AjaxResult Malifile(@RequestParam MultipartFile file){

        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }

    /***
     *
     * zip
     * @param file
     * @return
     */
    @PostMapping("/zipUrlFile")
    public AjaxResult zipUrlFile(@RequestParam MultipartFile file){
        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }


    /***
     *
     * 下载zip
     * @param file
     * @return
     */
    @PostMapping("/zipUrl")
    public AjaxResult zipUrl(@RequestParam MultipartFile file){
        String s = OssUtil.uploadMultipartFile(file);
        return AjaxResult.success(s);
    }


    /**
     * 添加工作流
     * @param requestWorkFlow
     * @return
     */
    @PostMapping("/addWorkFlow")
    public AjaxResult addWorkFlow(@RequestBody RequestWorkFlow requestWorkFlow){

        return workFlowService.addWorkFlow(requestWorkFlow);
    }

    /**
     * 修改工作流
     * @param requestWorkFlow
     * @return
     */
    @PostMapping("/updateWorkFlow")
    public AjaxResult updateWorkFlow(@RequestBody RequestWorkFlow requestWorkFlow){

        workFlowService.updateWorkFlow(requestWorkFlow);

        return AjaxResult.success("修改成功");
    }

    /**
     * 删除工作流
     * @param id
     * @return
     */
    @GetMapping("/deleteWorkFlow")
    public AjaxResult deleteWorkFlow(@RequestParam Long id){

        workFlowService.deleteWorkFlow(id);
        return AjaxResult.success("删除成功");
    }

    /**
     * 查询工作流列表
     * @param pageVo
     * @return
     */
    @PostMapping("/selectWorkFlow")
    public AjaxResult selectWorkFlow(@RequestBody PageVo pageVo){

        return workFlowService.selectWorkFlow(pageVo);
    }


    /**
     * 查询工作流详情
     * @param id
     * @return
     */
    @GetMapping("/selectWorkFlowById")
    public AjaxResult selectWorkFlowById(@RequestParam Long id){

        return workFlowService.selectWorkFlowById(id);
    }

}
