package com.mcwl.resource.domain;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import java.util.Date;
import java.util.List;

/**
 * 工作流表
 * @Author：ChenYan
 * @Project：McWl
 * @Package：com.mcwl.resource.domain
 * @Filename：WorkFlow
 * @Description 工作流表
 * @Version：1.0
 * @Date：2025/1/8 19:38
 */
@Builder
@AllArgsConstructor
@NoArgsConstructor
@Data
@TableName("work_flow")
public class WorkFlow {

    /**
     * 主键ID
     */
    @TableId
    private Long id;
    /**
     * 用户id
     */
    private Long userId;
    /**
     * 名称（最多30字）
     */
    private String workflowName;
    /**
     * 垂类
     */
    private String category;
    /**
     * 主题
     */
    private String theme;
    /**
     * 风格
     */
    private String style;
    /**
     * 功能
     */
    private String functions;
    /**
     * 参与活动
     */
    private String activityParticipation;
    /**
     * 删除标志（0代表存在 2代表删除）
     */
    private Integer delFlag;

    /**
     * 审核状态（0全部状态 1已发布-公开 2已发布-仅自己可见 3审核中 4审核未通过）
     */
    private Integer auditStatus = 3;

    /**
     *  审核失败原因
     */
    private String auditText;

    /**
     * 是否原创
     */
    private Integer original;

    /**
     * 原文作者名字
     */
    private String authorName;

    /**
     * 使用数量
     */
    private Long useNumber = 0L;

    /**
     *下载数量
     */
    private Long downloadNumber = 0L;

    /**
     * 是否允许在线使用(0允许 1不允许)
     */
    private Integer onlineUse;

    /**
     * 是否允许下载工作流(0允许 1不允许)
     */
    private Integer download;

    /**
     * 是否允许出售或商用(0允许 1不允许
     */
    private Integer sell;

    /**
     * 封面图地址
     */
    private String coverPath;

    /**
     * 审核权限
     */
    private Integer jurisdiction;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date createTime;

    /**
     * 更新时间
     */
    @JsonFormat(pattern = "yyyy-MM-dd",timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    private Date updateTime;

    /**
     * 作品点赞数量
     */
    private Long likeCount = 0L;

    /**
     * 翻译后主体
     */
    @TableField(exist = false)
    private List<String> themeList;

    /**
     * 翻译后风格
     */
    @TableField(exist = false)
    private List<String> styleList;
}
